#! /usr/bin/env python

'''
Python Interface to SAGA Tools Library
----------
- Category : Import/Export
- Name     : Web Services
- ID       : io_webservices

Description
----------
Web Services
'''

from PySAGA.helper import Tool_Wrapper

def Geocoding(
    ADDRESSES=None,
    LOCATIONS=None,
    FIELD=None,
    ADDRESS=None,
    PROVIDER=None,
    API_KEY=None,
    METADATA=None, Verbose=2):
    '''
    Geocoding
    ----------
    [io_webservices.0]\n
    Geocoding of addresses using geocoding services.\n
    Arguments
    ----------
    - ADDRESSES [`optional input table`] : Address List
    - LOCATIONS [`output shapes`] : Locations
    - FIELD [`table field`] : Address Field
    - ADDRESS [`text`] : Single Address. Default: Bundesstrasse 55, Hamburg, Germany
    - PROVIDER [`choice`] : Service Provider. Available Choices: [0] Nominatim (OpenStreetMap) [1] The Data Science Toolkit [2] Google [3] Bing [4] MapQuest Default: 0
    - API_KEY [`text`] : API Key
    - METADATA [`boolean`] : Store Metadata. Default: 0

    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
    Returns
    ----------
    `boolean` : `True` on success, `False` on failure.
    '''
    Tool = Tool_Wrapper('io_webservices', '0', 'Geocoding')
    if Tool.is_Okay():
        Tool.Set_Input ('ADDRESSES', ADDRESSES)
        Tool.Set_Output('LOCATIONS', LOCATIONS)
        Tool.Set_Option('FIELD', FIELD)
        Tool.Set_Option('ADDRESS', ADDRESS)
        Tool.Set_Option('PROVIDER', PROVIDER)
        Tool.Set_Option('API_KEY', API_KEY)
        Tool.Set_Option('METADATA', METADATA)
        return Tool.Execute(Verbose)
    return False

def run_tool_io_webservices_0(
    ADDRESSES=None,
    LOCATIONS=None,
    FIELD=None,
    ADDRESS=None,
    PROVIDER=None,
    API_KEY=None,
    METADATA=None, Verbose=2):
    '''
    Geocoding
    ----------
    [io_webservices.0]\n
    Geocoding of addresses using geocoding services.\n
    Arguments
    ----------
    - ADDRESSES [`optional input table`] : Address List
    - LOCATIONS [`output shapes`] : Locations
    - FIELD [`table field`] : Address Field
    - ADDRESS [`text`] : Single Address. Default: Bundesstrasse 55, Hamburg, Germany
    - PROVIDER [`choice`] : Service Provider. Available Choices: [0] Nominatim (OpenStreetMap) [1] The Data Science Toolkit [2] Google [3] Bing [4] MapQuest Default: 0
    - API_KEY [`text`] : API Key
    - METADATA [`boolean`] : Store Metadata. Default: 0

    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
    Returns
    ----------
    `boolean` : `True` on success, `False` on failure.
    '''
    Tool = Tool_Wrapper('io_webservices', '0', 'Geocoding')
    if Tool.is_Okay():
        Tool.Set_Input ('ADDRESSES', ADDRESSES)
        Tool.Set_Output('LOCATIONS', LOCATIONS)
        Tool.Set_Option('FIELD', FIELD)
        Tool.Set_Option('ADDRESS', ADDRESS)
        Tool.Set_Option('PROVIDER', PROVIDER)
        Tool.Set_Option('API_KEY', API_KEY)
        Tool.Set_Option('METADATA', METADATA)
        return Tool.Execute(Verbose)
    return False

def SRTM_CGIAR_CSI(
    GRID=None,
    SHAPES=None,
    RESULT=None,
    TILES=None,
    DELARCHIVE=None,
    EXTENT=None,
    GRID_SYSTEM=None,
    XMIN=None,
    XMAX=None,
    YMIN=None,
    YMAX=None,
    NX=None,
    NY=None,
    BUFFER=None,
    CELLSIZE=None,
    CRS_STRING=None, Verbose=2):
    '''
    SRTM (CGIAR CSI)
    ----------
    [io_webservices.1]\n
    This tool provides easy-to-use access to the 'NASA Shuttle Radar Topography Mission Global 3 arc second' elevation data (about 90 meter resolution) as provided by the CGIAR CSI server. It uses a local database in the chosen directory which provides the original tiles. If the tiles covering the requested area are not found in this directory the tool tries to download these from the CGIAR CSI server.\n
    Arguments
    ----------
    - GRID [`input grid`] : Grid
    - SHAPES [`input shapes`] : Shapes
    - RESULT [`output data object`] : Grid
    - TILES [`file path`] : Local Tiles Directory. Download location for tiles. If requested tile is already present download will be skipped.
    - DELARCHIVE [`boolean`] : Delete Archive Files. Default: 1 Do not keep archive files after download
    - EXTENT [`choice`] : Extent. Available Choices: [0] user defined [1] shapes extent [2] grid system extent [3] grid system Default: 0
    - GRID_SYSTEM [`grid system`] : Grid System
    - XMIN [`floating point number`] : West. Default: 270360.000000
    - XMAX [`floating point number`] : East. Default: 931320.000000
    - YMIN [`floating point number`] : South. Default: 5225850.000000
    - YMAX [`floating point number`] : North. Default: 6111540.000000
    - NX [`integer number`] : Columns. Minimum: 1 Default: 7345
    - NY [`integer number`] : Rows. Minimum: 1 Default: 9842
    - BUFFER [`floating point number`] : Buffer. Minimum: 0.000000 Default: 0.000000 add buffer (map units) to extent
    - CELLSIZE [`floating point number`] : Cellsize. Minimum: 0.000100 Default: 90.000000
    - CRS_STRING [`text`] : Coordinate System Definition. Supported formats comprise PROJ and WKT strings, object codes (e.g. "EPSG:4326").

    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
    Returns
    ----------
    `boolean` : `True` on success, `False` on failure.
    '''
    Tool = Tool_Wrapper('io_webservices', '1', 'SRTM (CGIAR CSI)')
    if Tool.is_Okay():
        Tool.Set_Input ('GRID', GRID)
        Tool.Set_Input ('SHAPES', SHAPES)
        Tool.Set_Output('RESULT', RESULT)
        Tool.Set_Option('TILES', TILES)
        Tool.Set_Option('DELARCHIVE', DELARCHIVE)
        Tool.Set_Option('EXTENT', EXTENT)
        Tool.Set_Option('GRID_SYSTEM', GRID_SYSTEM)
        Tool.Set_Option('XMIN', XMIN)
        Tool.Set_Option('XMAX', XMAX)
        Tool.Set_Option('YMIN', YMIN)
        Tool.Set_Option('YMAX', YMAX)
        Tool.Set_Option('NX', NX)
        Tool.Set_Option('NY', NY)
        Tool.Set_Option('BUFFER', BUFFER)
        Tool.Set_Option('CELLSIZE', CELLSIZE)
        Tool.Set_Option('CRS_STRING', CRS_STRING)
        return Tool.Execute(Verbose)
    return False

def run_tool_io_webservices_1(
    GRID=None,
    SHAPES=None,
    RESULT=None,
    TILES=None,
    DELARCHIVE=None,
    EXTENT=None,
    GRID_SYSTEM=None,
    XMIN=None,
    XMAX=None,
    YMIN=None,
    YMAX=None,
    NX=None,
    NY=None,
    BUFFER=None,
    CELLSIZE=None,
    CRS_STRING=None, Verbose=2):
    '''
    SRTM (CGIAR CSI)
    ----------
    [io_webservices.1]\n
    This tool provides easy-to-use access to the 'NASA Shuttle Radar Topography Mission Global 3 arc second' elevation data (about 90 meter resolution) as provided by the CGIAR CSI server. It uses a local database in the chosen directory which provides the original tiles. If the tiles covering the requested area are not found in this directory the tool tries to download these from the CGIAR CSI server.\n
    Arguments
    ----------
    - GRID [`input grid`] : Grid
    - SHAPES [`input shapes`] : Shapes
    - RESULT [`output data object`] : Grid
    - TILES [`file path`] : Local Tiles Directory. Download location for tiles. If requested tile is already present download will be skipped.
    - DELARCHIVE [`boolean`] : Delete Archive Files. Default: 1 Do not keep archive files after download
    - EXTENT [`choice`] : Extent. Available Choices: [0] user defined [1] shapes extent [2] grid system extent [3] grid system Default: 0
    - GRID_SYSTEM [`grid system`] : Grid System
    - XMIN [`floating point number`] : West. Default: 270360.000000
    - XMAX [`floating point number`] : East. Default: 931320.000000
    - YMIN [`floating point number`] : South. Default: 5225850.000000
    - YMAX [`floating point number`] : North. Default: 6111540.000000
    - NX [`integer number`] : Columns. Minimum: 1 Default: 7345
    - NY [`integer number`] : Rows. Minimum: 1 Default: 9842
    - BUFFER [`floating point number`] : Buffer. Minimum: 0.000000 Default: 0.000000 add buffer (map units) to extent
    - CELLSIZE [`floating point number`] : Cellsize. Minimum: 0.000100 Default: 90.000000
    - CRS_STRING [`text`] : Coordinate System Definition. Supported formats comprise PROJ and WKT strings, object codes (e.g. "EPSG:4326").

    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
    Returns
    ----------
    `boolean` : `True` on success, `False` on failure.
    '''
    Tool = Tool_Wrapper('io_webservices', '1', 'SRTM (CGIAR CSI)')
    if Tool.is_Okay():
        Tool.Set_Input ('GRID', GRID)
        Tool.Set_Input ('SHAPES', SHAPES)
        Tool.Set_Output('RESULT', RESULT)
        Tool.Set_Option('TILES', TILES)
        Tool.Set_Option('DELARCHIVE', DELARCHIVE)
        Tool.Set_Option('EXTENT', EXTENT)
        Tool.Set_Option('GRID_SYSTEM', GRID_SYSTEM)
        Tool.Set_Option('XMIN', XMIN)
        Tool.Set_Option('XMAX', XMAX)
        Tool.Set_Option('YMIN', YMIN)
        Tool.Set_Option('YMAX', YMAX)
        Tool.Set_Option('NX', NX)
        Tool.Set_Option('NY', NY)
        Tool.Set_Option('BUFFER', BUFFER)
        Tool.Set_Option('CELLSIZE', CELLSIZE)
        Tool.Set_Option('CRS_STRING', CRS_STRING)
        return Tool.Execute(Verbose)
    return False

def Global_OpenTopography(
    GRID=None,
    SHAPES=None,
    RESULT=None,
    DEMTYPE=None,
    API_KEY=None,
    EXTENT=None,
    GRID_SYSTEM=None,
    XMIN=None,
    XMAX=None,
    YMIN=None,
    YMAX=None,
    NX=None,
    NY=None,
    BUFFER=None,
    CELLSIZEDEF=None,
    CELLSIZE=None,
    CRS_STRING=None, Verbose=2):
    '''
    Global OpenTopography
    ----------
    [io_webservices.4]\n
    Download and optionally project global digital elevation model (DEM) data for the area of your interest provided by the OpenTopography project. The download needs a personal [API key] which can be obtained easily after login at the OpenTopography Data Portal.\n
    Available DEM products are:\n
    (-) SRTM GL3 90m\n
    (-) SRTM GL1 30m\n
    (-) SRTM GL1 Ellipsoidal 30m\n
    (-) ALOS World 3D 30m\n
    (-) ALOS World 3D Ellipsoidal, 30m\n
    (-) Global Bathymetry SRTM15+ V2.1 500m\n
    (-) NASADEM Global DEM\n
    (-) Copernicus Global DSM 30m\n
    (-) Copernicus Global DSM 90m\n
    (-) EU DTM 30m\n
    (-) GEDI_L3 DTM 1000m\n
    (-) Global Ice Bathymetry 500m\n
    (-) Global Sub-Ice Bathymetry 500m\n
    Arguments
    ----------
    - GRID [`input grid`] : Grid
    - SHAPES [`input shapes`] : Shapes
    - RESULT [`output data object`] : Grid
    - DEMTYPE [`choice`] : DEM Type. Available Choices: [0] SRTM GL3 90m [1] SRTM GL1 30m [2] SRTM GL1 Ellipsoidal 30m [3] ALOS World 3D 30m [4] ALOS World 3D Ellipsoidal, 30m [5] Global Bathymetry SRTM15+ V2.1 500m [6] NASADEM Global DEM [7] Copernicus Global DSM 30m [8] Copernicus Global DSM 90m [9] EU DTM 30m [10] GEDI_L3 DTM 1000m [11] Global Ice Bathymetry 500m [12] Global Sub-Ice Bathymetry 500m Default: 3
    - API_KEY [`text`] : API Key
    - EXTENT [`choice`] : Extent. Available Choices: [0] user defined [1] shapes extent [2] grid system extent [3] grid system Default: 0
    - GRID_SYSTEM [`grid system`] : Grid System
    - XMIN [`floating point number`] : West. Default: 538350.000000
    - XMAX [`floating point number`] : East. Default: 598020.000000
    - YMIN [`floating point number`] : South. Default: 5906910.000000
    - YMAX [`floating point number`] : North. Default: 5965170.000000
    - NX [`integer number`] : Columns. Minimum: 1 Default: 1990
    - NY [`integer number`] : Rows. Minimum: 1 Default: 1943
    - BUFFER [`floating point number`] : Buffer. Minimum: 0.000000 Default: 0.000000 add buffer (map units) to extent
    - CELLSIZEDEF [`choice`] : Take Cellsize. Available Choices: [0] data type resolution [1] user defined Default: 0
    - CELLSIZE [`floating point number`] : Cellsize. Minimum: 0.000100 Default: 90.000000
    - CRS_STRING [`text`] : Coordinate System Definition. Supported formats comprise PROJ and WKT strings, object codes (e.g. "EPSG:4326").

    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
    Returns
    ----------
    `boolean` : `True` on success, `False` on failure.
    '''
    Tool = Tool_Wrapper('io_webservices', '4', 'Global OpenTopography')
    if Tool.is_Okay():
        Tool.Set_Input ('GRID', GRID)
        Tool.Set_Input ('SHAPES', SHAPES)
        Tool.Set_Output('RESULT', RESULT)
        Tool.Set_Option('DEMTYPE', DEMTYPE)
        Tool.Set_Option('API_KEY', API_KEY)
        Tool.Set_Option('EXTENT', EXTENT)
        Tool.Set_Option('GRID_SYSTEM', GRID_SYSTEM)
        Tool.Set_Option('XMIN', XMIN)
        Tool.Set_Option('XMAX', XMAX)
        Tool.Set_Option('YMIN', YMIN)
        Tool.Set_Option('YMAX', YMAX)
        Tool.Set_Option('NX', NX)
        Tool.Set_Option('NY', NY)
        Tool.Set_Option('BUFFER', BUFFER)
        Tool.Set_Option('CELLSIZEDEF', CELLSIZEDEF)
        Tool.Set_Option('CELLSIZE', CELLSIZE)
        Tool.Set_Option('CRS_STRING', CRS_STRING)
        return Tool.Execute(Verbose)
    return False

def run_tool_io_webservices_4(
    GRID=None,
    SHAPES=None,
    RESULT=None,
    DEMTYPE=None,
    API_KEY=None,
    EXTENT=None,
    GRID_SYSTEM=None,
    XMIN=None,
    XMAX=None,
    YMIN=None,
    YMAX=None,
    NX=None,
    NY=None,
    BUFFER=None,
    CELLSIZEDEF=None,
    CELLSIZE=None,
    CRS_STRING=None, Verbose=2):
    '''
    Global OpenTopography
    ----------
    [io_webservices.4]\n
    Download and optionally project global digital elevation model (DEM) data for the area of your interest provided by the OpenTopography project. The download needs a personal [API key] which can be obtained easily after login at the OpenTopography Data Portal.\n
    Available DEM products are:\n
    (-) SRTM GL3 90m\n
    (-) SRTM GL1 30m\n
    (-) SRTM GL1 Ellipsoidal 30m\n
    (-) ALOS World 3D 30m\n
    (-) ALOS World 3D Ellipsoidal, 30m\n
    (-) Global Bathymetry SRTM15+ V2.1 500m\n
    (-) NASADEM Global DEM\n
    (-) Copernicus Global DSM 30m\n
    (-) Copernicus Global DSM 90m\n
    (-) EU DTM 30m\n
    (-) GEDI_L3 DTM 1000m\n
    (-) Global Ice Bathymetry 500m\n
    (-) Global Sub-Ice Bathymetry 500m\n
    Arguments
    ----------
    - GRID [`input grid`] : Grid
    - SHAPES [`input shapes`] : Shapes
    - RESULT [`output data object`] : Grid
    - DEMTYPE [`choice`] : DEM Type. Available Choices: [0] SRTM GL3 90m [1] SRTM GL1 30m [2] SRTM GL1 Ellipsoidal 30m [3] ALOS World 3D 30m [4] ALOS World 3D Ellipsoidal, 30m [5] Global Bathymetry SRTM15+ V2.1 500m [6] NASADEM Global DEM [7] Copernicus Global DSM 30m [8] Copernicus Global DSM 90m [9] EU DTM 30m [10] GEDI_L3 DTM 1000m [11] Global Ice Bathymetry 500m [12] Global Sub-Ice Bathymetry 500m Default: 3
    - API_KEY [`text`] : API Key
    - EXTENT [`choice`] : Extent. Available Choices: [0] user defined [1] shapes extent [2] grid system extent [3] grid system Default: 0
    - GRID_SYSTEM [`grid system`] : Grid System
    - XMIN [`floating point number`] : West. Default: 538350.000000
    - XMAX [`floating point number`] : East. Default: 598020.000000
    - YMIN [`floating point number`] : South. Default: 5906910.000000
    - YMAX [`floating point number`] : North. Default: 5965170.000000
    - NX [`integer number`] : Columns. Minimum: 1 Default: 1990
    - NY [`integer number`] : Rows. Minimum: 1 Default: 1943
    - BUFFER [`floating point number`] : Buffer. Minimum: 0.000000 Default: 0.000000 add buffer (map units) to extent
    - CELLSIZEDEF [`choice`] : Take Cellsize. Available Choices: [0] data type resolution [1] user defined Default: 0
    - CELLSIZE [`floating point number`] : Cellsize. Minimum: 0.000100 Default: 90.000000
    - CRS_STRING [`text`] : Coordinate System Definition. Supported formats comprise PROJ and WKT strings, object codes (e.g. "EPSG:4326").

    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
    Returns
    ----------
    `boolean` : `True` on success, `False` on failure.
    '''
    Tool = Tool_Wrapper('io_webservices', '4', 'Global OpenTopography')
    if Tool.is_Okay():
        Tool.Set_Input ('GRID', GRID)
        Tool.Set_Input ('SHAPES', SHAPES)
        Tool.Set_Output('RESULT', RESULT)
        Tool.Set_Option('DEMTYPE', DEMTYPE)
        Tool.Set_Option('API_KEY', API_KEY)
        Tool.Set_Option('EXTENT', EXTENT)
        Tool.Set_Option('GRID_SYSTEM', GRID_SYSTEM)
        Tool.Set_Option('XMIN', XMIN)
        Tool.Set_Option('XMAX', XMAX)
        Tool.Set_Option('YMIN', YMIN)
        Tool.Set_Option('YMAX', YMAX)
        Tool.Set_Option('NX', NX)
        Tool.Set_Option('NY', NY)
        Tool.Set_Option('BUFFER', BUFFER)
        Tool.Set_Option('CELLSIZEDEF', CELLSIZEDEF)
        Tool.Set_Option('CELLSIZE', CELLSIZE)
        Tool.Set_Option('CRS_STRING', CRS_STRING)
        return Tool.Execute(Verbose)
    return False

def USGS_Earthquake_Catalog(
    SHAPES=None,
    GRID=None,
    EARTHQUAKES=None,
    DATE_START=None,
    DATE_END=None,
    MAGNITUDE=None,
    EXTENT=None,
    GRID_SYSTEM=None,
    XMIN=None,
    XMAX=None,
    YMIN=None,
    YMAX=None,
    BUFFER=None,
    CRS_STRING=None, Verbose=2):
    '''
    USGS Earthquake Catalog
    ----------
    [io_webservices.5]\n
    Request earthquake data from the USGS Earthquake Catalog.\n
    Arguments
    ----------
    - SHAPES [`input shapes`] : Shapes
    - GRID [`optional input grid`] : Grid
    - EARTHQUAKES [`output shapes`] : Earthquakes
    - DATE_START [`date`] : Start. Default: 2025-03-25
    - DATE_END [`date`] : End. Default: 2025-04-01
    - MAGNITUDE [`value range`] : Magnitude
    - EXTENT [`choice`] : Extent. Available Choices: [0] user defined [1] shapes extent [2] grid system extent Default: 0
    - GRID_SYSTEM [`grid system`] : Grid System
    - XMIN [`floating point number`] : West. Default: -180.000000
    - XMAX [`floating point number`] : East. Default: 180.000000
    - YMIN [`floating point number`] : South. Default: -90.000000
    - YMAX [`floating point number`] : North. Default: 90.000000
    - BUFFER [`floating point number`] : Buffer. Minimum: 0.000000 Default: 0.000000 add buffer (map units) to extent
    - CRS_STRING [`text`] : Coordinate System Definition. Supported formats comprise PROJ and WKT strings, object codes (e.g. "EPSG:4326").

    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
    Returns
    ----------
    `boolean` : `True` on success, `False` on failure.
    '''
    Tool = Tool_Wrapper('io_webservices', '5', 'USGS Earthquake Catalog')
    if Tool.is_Okay():
        Tool.Set_Input ('SHAPES', SHAPES)
        Tool.Set_Input ('GRID', GRID)
        Tool.Set_Output('EARTHQUAKES', EARTHQUAKES)
        Tool.Set_Option('DATE_START', DATE_START)
        Tool.Set_Option('DATE_END', DATE_END)
        Tool.Set_Option('MAGNITUDE', MAGNITUDE)
        Tool.Set_Option('EXTENT', EXTENT)
        Tool.Set_Option('GRID_SYSTEM', GRID_SYSTEM)
        Tool.Set_Option('XMIN', XMIN)
        Tool.Set_Option('XMAX', XMAX)
        Tool.Set_Option('YMIN', YMIN)
        Tool.Set_Option('YMAX', YMAX)
        Tool.Set_Option('BUFFER', BUFFER)
        Tool.Set_Option('CRS_STRING', CRS_STRING)
        return Tool.Execute(Verbose)
    return False

def run_tool_io_webservices_5(
    SHAPES=None,
    GRID=None,
    EARTHQUAKES=None,
    DATE_START=None,
    DATE_END=None,
    MAGNITUDE=None,
    EXTENT=None,
    GRID_SYSTEM=None,
    XMIN=None,
    XMAX=None,
    YMIN=None,
    YMAX=None,
    BUFFER=None,
    CRS_STRING=None, Verbose=2):
    '''
    USGS Earthquake Catalog
    ----------
    [io_webservices.5]\n
    Request earthquake data from the USGS Earthquake Catalog.\n
    Arguments
    ----------
    - SHAPES [`input shapes`] : Shapes
    - GRID [`optional input grid`] : Grid
    - EARTHQUAKES [`output shapes`] : Earthquakes
    - DATE_START [`date`] : Start. Default: 2025-03-25
    - DATE_END [`date`] : End. Default: 2025-04-01
    - MAGNITUDE [`value range`] : Magnitude
    - EXTENT [`choice`] : Extent. Available Choices: [0] user defined [1] shapes extent [2] grid system extent Default: 0
    - GRID_SYSTEM [`grid system`] : Grid System
    - XMIN [`floating point number`] : West. Default: -180.000000
    - XMAX [`floating point number`] : East. Default: 180.000000
    - YMIN [`floating point number`] : South. Default: -90.000000
    - YMAX [`floating point number`] : North. Default: 90.000000
    - BUFFER [`floating point number`] : Buffer. Minimum: 0.000000 Default: 0.000000 add buffer (map units) to extent
    - CRS_STRING [`text`] : Coordinate System Definition. Supported formats comprise PROJ and WKT strings, object codes (e.g. "EPSG:4326").

    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
    Returns
    ----------
    `boolean` : `True` on success, `False` on failure.
    '''
    Tool = Tool_Wrapper('io_webservices', '5', 'USGS Earthquake Catalog')
    if Tool.is_Okay():
        Tool.Set_Input ('SHAPES', SHAPES)
        Tool.Set_Input ('GRID', GRID)
        Tool.Set_Output('EARTHQUAKES', EARTHQUAKES)
        Tool.Set_Option('DATE_START', DATE_START)
        Tool.Set_Option('DATE_END', DATE_END)
        Tool.Set_Option('MAGNITUDE', MAGNITUDE)
        Tool.Set_Option('EXTENT', EXTENT)
        Tool.Set_Option('GRID_SYSTEM', GRID_SYSTEM)
        Tool.Set_Option('XMIN', XMIN)
        Tool.Set_Option('XMAX', XMAX)
        Tool.Set_Option('YMIN', YMIN)
        Tool.Set_Option('YMAX', YMAX)
        Tool.Set_Option('BUFFER', BUFFER)
        Tool.Set_Option('CRS_STRING', CRS_STRING)
        return Tool.Execute(Verbose)
    return False




#! /usr/bin/env python

'''
Python Interface to SAGA Tools Library
----------
- Category : Terrain Analysis
- Name     : CliffMetrics
- ID       : ta_cliffmetrics

Description
----------
CliffMetrics (Automatic Cliff Metrics delineation) delineates the location of the coastline, coastline normals, and cliff top and toe location along these normals. 
'''

from PySAGA.helper import Tool_Wrapper

def CliffMetrics(
    DEM=None,
    COAST_INITIAL=None,
    SEDIMENT_TOP=None,
    RASTER_COAST=None,
    RASTER_NORMAL=None,
    COAST=None,
    NORMALS=None,
    CLIFF_TOP=None,
    CLIFF_TOE=None,
    COAST_POINT=None,
    INVALID_NORMALS=None,
    COAST_CURVATURE=None,
    PROFILES=None,
    COASTSEAHANDINESS=None,
    STARTEDGEUSERCOASTLINE=None,
    ENDEDGEUSERCOASTLINE=None,
    STILLWATERLEVEL=None,
    COASTSMOOTH=None,
    COASTSMOOTHWINDOW=None,
    SAVGOLCOASTPOLY=None,
    SCALERASTEROUTPUT=None,
    RANDOMCOASTEDGESEARCH=None,
    COASTNORMALLENGTH=None,
    ELETOLERANCE=None,
    OUTPATH=None, Verbose=2):
    '''
    CliffMetrics
    ----------
    [ta_cliffmetrics.0]\n
    CliffMetrics (Automatic Cliff Metrics delineation) delineates the location of the coastline, coastline normals, and cliff top and toe location along these normals.\n
    Arguments
    ----------
    - DEM [`input grid`] : Elevation
    - COAST_INITIAL [`optional input shapes`] : User Defined Coastline Points. if non empty, cliffmetric will use the user defined coastal line to draw the transects
    - SEDIMENT_TOP [`output grid`] : Sediment Top Elevation
    - RASTER_COAST [`output grid`] : Coastline
    - RASTER_NORMAL [`output grid`] : Normals
    - COAST [`output shapes`] : Coastline
    - NORMALS [`output shapes`] : Coastline-Normal Profiles
    - CLIFF_TOP [`output shapes`] : Cliff Top Points
    - CLIFF_TOE [`output shapes`] : Cliff Toe Points
    - COAST_POINT [`output shapes`] : Coast Points
    - INVALID_NORMALS [`output shapes`] : Invalid Coastline-Normal Profiles
    - COAST_CURVATURE [`output shapes`] : Coastline Curvature
    - PROFILES [`output table`] : Profile Data
    - COASTSEAHANDINESS [`choice`] : Sea handiness. Available Choices: [0] right [1] left Default: 0 as you traverse the coastline, on which side of shoreline the sea is?
    - STARTEDGEUSERCOASTLINE [`choice`] : Start edge coastline. Available Choices: [0] North [1] East [2] South [3] West Default: 0 on which edge of the DTM the start of coastline is?
    - ENDEDGEUSERCOASTLINE [`choice`] : End edge coastline. Available Choices: [0] North [1] East [2] South [3] West Default: 0 on which edge of the DTM the end of coastline is?
    - STILLWATERLEVEL [`floating point number`] : Still Water Level. Minimum: 0.000000 Default: 1.000000 Still water level (m) used to extract the shoreline.
    - COASTSMOOTH [`choice`] : Coastline Smoothing Algorithm. Available Choices: [0] none [1] running mean [2] Savitsky-Golay Default: 1 Vector coastline smoothing algorithm.
    - COASTSMOOTHWINDOW [`integer number`] : Coastline Smoothing Window Size. Minimum: 1 Default: 30 Size of coastline smoothing window, resulting kernel size will be: 1 + 2 * size.
    - SAVGOLCOASTPOLY [`integer number`] : Polynomial Order for Savitsky-Golay. Minimum: 1 Maximum: 6 Default: 4 Order of coastline profile smoothing polynomial for Savitsky-Golay smoothing: usually 2 or 4, max is 6.
    - SCALERASTEROUTPUT [`boolean`] : Scale Raster Output Values. Default: 1 If needed, scale GIS raster output values.
    - RANDOMCOASTEDGESEARCH [`boolean`] : Random Edge for Coastline Search. Default: 1 Random edge for coastline search.
    - COASTNORMALLENGTH [`floating point number`] : Length of Coastline Normals. Minimum: 0.010000 Default: 500.000000 Length of coastline normals (m).
    - ELETOLERANCE [`floating point number`] : Vertical Tolerance. Minimum: 0.010000 Default: 0.500000 Vertical tolerance to avoid false cliff tops and toes.
    - OUTPATH [`file path`] : Main Output File Directory

    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
    Returns
    ----------
    `boolean` : `True` on success, `False` on failure.
    '''
    Tool = Tool_Wrapper('ta_cliffmetrics', '0', 'CliffMetrics')
    if Tool.is_Okay():
        Tool.Set_Input ('DEM', DEM)
        Tool.Set_Input ('COAST_INITIAL', COAST_INITIAL)
        Tool.Set_Output('SEDIMENT_TOP', SEDIMENT_TOP)
        Tool.Set_Output('RASTER_COAST', RASTER_COAST)
        Tool.Set_Output('RASTER_NORMAL', RASTER_NORMAL)
        Tool.Set_Output('COAST', COAST)
        Tool.Set_Output('NORMALS', NORMALS)
        Tool.Set_Output('CLIFF_TOP', CLIFF_TOP)
        Tool.Set_Output('CLIFF_TOE', CLIFF_TOE)
        Tool.Set_Output('COAST_POINT', COAST_POINT)
        Tool.Set_Output('INVALID_NORMALS', INVALID_NORMALS)
        Tool.Set_Output('COAST_CURVATURE', COAST_CURVATURE)
        Tool.Set_Output('PROFILES', PROFILES)
        Tool.Set_Option('CoastSeaHandiness', COASTSEAHANDINESS)
        Tool.Set_Option('StartEdgeUserCoastLine', STARTEDGEUSERCOASTLINE)
        Tool.Set_Option('EndEdgeUserCoastLine', ENDEDGEUSERCOASTLINE)
        Tool.Set_Option('StillWaterLevel', STILLWATERLEVEL)
        Tool.Set_Option('CoastSmooth', COASTSMOOTH)
        Tool.Set_Option('CoastSmoothWindow', COASTSMOOTHWINDOW)
        Tool.Set_Option('SavGolCoastPoly', SAVGOLCOASTPOLY)
        Tool.Set_Option('ScaleRasterOutput', SCALERASTEROUTPUT)
        Tool.Set_Option('RandomCoastEdgeSearch', RANDOMCOASTEDGESEARCH)
        Tool.Set_Option('CoastNormalLength', COASTNORMALLENGTH)
        Tool.Set_Option('EleTolerance', ELETOLERANCE)
        Tool.Set_Option('OutPath', OUTPATH)
        return Tool.Execute(Verbose)
    return False

def run_tool_ta_cliffmetrics_0(
    DEM=None,
    COAST_INITIAL=None,
    SEDIMENT_TOP=None,
    RASTER_COAST=None,
    RASTER_NORMAL=None,
    COAST=None,
    NORMALS=None,
    CLIFF_TOP=None,
    CLIFF_TOE=None,
    COAST_POINT=None,
    INVALID_NORMALS=None,
    COAST_CURVATURE=None,
    PROFILES=None,
    COASTSEAHANDINESS=None,
    STARTEDGEUSERCOASTLINE=None,
    ENDEDGEUSERCOASTLINE=None,
    STILLWATERLEVEL=None,
    COASTSMOOTH=None,
    COASTSMOOTHWINDOW=None,
    SAVGOLCOASTPOLY=None,
    SCALERASTEROUTPUT=None,
    RANDOMCOASTEDGESEARCH=None,
    COASTNORMALLENGTH=None,
    ELETOLERANCE=None,
    OUTPATH=None, Verbose=2):
    '''
    CliffMetrics
    ----------
    [ta_cliffmetrics.0]\n
    CliffMetrics (Automatic Cliff Metrics delineation) delineates the location of the coastline, coastline normals, and cliff top and toe location along these normals.\n
    Arguments
    ----------
    - DEM [`input grid`] : Elevation
    - COAST_INITIAL [`optional input shapes`] : User Defined Coastline Points. if non empty, cliffmetric will use the user defined coastal line to draw the transects
    - SEDIMENT_TOP [`output grid`] : Sediment Top Elevation
    - RASTER_COAST [`output grid`] : Coastline
    - RASTER_NORMAL [`output grid`] : Normals
    - COAST [`output shapes`] : Coastline
    - NORMALS [`output shapes`] : Coastline-Normal Profiles
    - CLIFF_TOP [`output shapes`] : Cliff Top Points
    - CLIFF_TOE [`output shapes`] : Cliff Toe Points
    - COAST_POINT [`output shapes`] : Coast Points
    - INVALID_NORMALS [`output shapes`] : Invalid Coastline-Normal Profiles
    - COAST_CURVATURE [`output shapes`] : Coastline Curvature
    - PROFILES [`output table`] : Profile Data
    - COASTSEAHANDINESS [`choice`] : Sea handiness. Available Choices: [0] right [1] left Default: 0 as you traverse the coastline, on which side of shoreline the sea is?
    - STARTEDGEUSERCOASTLINE [`choice`] : Start edge coastline. Available Choices: [0] North [1] East [2] South [3] West Default: 0 on which edge of the DTM the start of coastline is?
    - ENDEDGEUSERCOASTLINE [`choice`] : End edge coastline. Available Choices: [0] North [1] East [2] South [3] West Default: 0 on which edge of the DTM the end of coastline is?
    - STILLWATERLEVEL [`floating point number`] : Still Water Level. Minimum: 0.000000 Default: 1.000000 Still water level (m) used to extract the shoreline.
    - COASTSMOOTH [`choice`] : Coastline Smoothing Algorithm. Available Choices: [0] none [1] running mean [2] Savitsky-Golay Default: 1 Vector coastline smoothing algorithm.
    - COASTSMOOTHWINDOW [`integer number`] : Coastline Smoothing Window Size. Minimum: 1 Default: 30 Size of coastline smoothing window, resulting kernel size will be: 1 + 2 * size.
    - SAVGOLCOASTPOLY [`integer number`] : Polynomial Order for Savitsky-Golay. Minimum: 1 Maximum: 6 Default: 4 Order of coastline profile smoothing polynomial for Savitsky-Golay smoothing: usually 2 or 4, max is 6.
    - SCALERASTEROUTPUT [`boolean`] : Scale Raster Output Values. Default: 1 If needed, scale GIS raster output values.
    - RANDOMCOASTEDGESEARCH [`boolean`] : Random Edge for Coastline Search. Default: 1 Random edge for coastline search.
    - COASTNORMALLENGTH [`floating point number`] : Length of Coastline Normals. Minimum: 0.010000 Default: 500.000000 Length of coastline normals (m).
    - ELETOLERANCE [`floating point number`] : Vertical Tolerance. Minimum: 0.010000 Default: 0.500000 Vertical tolerance to avoid false cliff tops and toes.
    - OUTPATH [`file path`] : Main Output File Directory

    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
    Returns
    ----------
    `boolean` : `True` on success, `False` on failure.
    '''
    Tool = Tool_Wrapper('ta_cliffmetrics', '0', 'CliffMetrics')
    if Tool.is_Okay():
        Tool.Set_Input ('DEM', DEM)
        Tool.Set_Input ('COAST_INITIAL', COAST_INITIAL)
        Tool.Set_Output('SEDIMENT_TOP', SEDIMENT_TOP)
        Tool.Set_Output('RASTER_COAST', RASTER_COAST)
        Tool.Set_Output('RASTER_NORMAL', RASTER_NORMAL)
        Tool.Set_Output('COAST', COAST)
        Tool.Set_Output('NORMALS', NORMALS)
        Tool.Set_Output('CLIFF_TOP', CLIFF_TOP)
        Tool.Set_Output('CLIFF_TOE', CLIFF_TOE)
        Tool.Set_Output('COAST_POINT', COAST_POINT)
        Tool.Set_Output('INVALID_NORMALS', INVALID_NORMALS)
        Tool.Set_Output('COAST_CURVATURE', COAST_CURVATURE)
        Tool.Set_Output('PROFILES', PROFILES)
        Tool.Set_Option('CoastSeaHandiness', COASTSEAHANDINESS)
        Tool.Set_Option('StartEdgeUserCoastLine', STARTEDGEUSERCOASTLINE)
        Tool.Set_Option('EndEdgeUserCoastLine', ENDEDGEUSERCOASTLINE)
        Tool.Set_Option('StillWaterLevel', STILLWATERLEVEL)
        Tool.Set_Option('CoastSmooth', COASTSMOOTH)
        Tool.Set_Option('CoastSmoothWindow', COASTSMOOTHWINDOW)
        Tool.Set_Option('SavGolCoastPoly', SAVGOLCOASTPOLY)
        Tool.Set_Option('ScaleRasterOutput', SCALERASTEROUTPUT)
        Tool.Set_Option('RandomCoastEdgeSearch', RANDOMCOASTEDGESEARCH)
        Tool.Set_Option('CoastNormalLength', COASTNORMALLENGTH)
        Tool.Set_Option('EleTolerance', ELETOLERANCE)
        Tool.Set_Option('OutPath', OUTPATH)
        return Tool.Execute(Verbose)
    return False

def Coastal_Profile_Crossings(
    LINES_SEASIDE=None,
    LINES_LANDSIDE=None,
    LINES_COAST=None,
    CROSSINGS_SEASIDE=None,
    CROSSINGS_LANDSIDE=None,
    DISTANCES=None,
    ATTRIBUTES=None, Verbose=2):
    '''
    Coastal Profile Crossings
    ----------
    [ta_cliffmetrics.1]\n
    The Coastal Profile Crossings tool identifies the crossing points between coastal profiles along a reference coastline (from CliffMetrics Normal outputs) and any other coast lines and calculates the distance and coastline differences metrics.\n
    Arguments
    ----------
    - LINES_SEASIDE [`input shapes`] : SeaSide Profile Lines Layer
    - LINES_LANDSIDE [`input shapes`] : LandSide Profile Lines Layer
    - LINES_COAST [`input shapes`] : Coast Lines Layer
    - CROSSINGS_SEASIDE [`output shapes`] : Crossings at Sea Side
    - CROSSINGS_LANDSIDE [`output shapes`] : Crossings at Land Side
    - DISTANCES [`output shapes`] : Distances to profile start point. Distances > 0 if towards sea side (acretion) and < 0 if towards landside (erosion)
    - ATTRIBUTES [`choice`] : Parent Attributes. Available Choices: [0] index [1] attributes [2] index and attributes Default: 0 attributes inherited by parent lines layers

    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
    Returns
    ----------
    `boolean` : `True` on success, `False` on failure.
    '''
    Tool = Tool_Wrapper('ta_cliffmetrics', '1', 'Coastal Profile Crossings')
    if Tool.is_Okay():
        Tool.Set_Input ('LINES_SeaSide', LINES_SEASIDE)
        Tool.Set_Input ('LINES_LandSide', LINES_LANDSIDE)
        Tool.Set_Input ('LINES_Coast', LINES_COAST)
        Tool.Set_Output('CROSSINGS_SEASIDE', CROSSINGS_SEASIDE)
        Tool.Set_Output('CROSSINGS_LANDSIDE', CROSSINGS_LANDSIDE)
        Tool.Set_Output('DISTANCES', DISTANCES)
        Tool.Set_Option('ATTRIBUTES', ATTRIBUTES)
        return Tool.Execute(Verbose)
    return False

def run_tool_ta_cliffmetrics_1(
    LINES_SEASIDE=None,
    LINES_LANDSIDE=None,
    LINES_COAST=None,
    CROSSINGS_SEASIDE=None,
    CROSSINGS_LANDSIDE=None,
    DISTANCES=None,
    ATTRIBUTES=None, Verbose=2):
    '''
    Coastal Profile Crossings
    ----------
    [ta_cliffmetrics.1]\n
    The Coastal Profile Crossings tool identifies the crossing points between coastal profiles along a reference coastline (from CliffMetrics Normal outputs) and any other coast lines and calculates the distance and coastline differences metrics.\n
    Arguments
    ----------
    - LINES_SEASIDE [`input shapes`] : SeaSide Profile Lines Layer
    - LINES_LANDSIDE [`input shapes`] : LandSide Profile Lines Layer
    - LINES_COAST [`input shapes`] : Coast Lines Layer
    - CROSSINGS_SEASIDE [`output shapes`] : Crossings at Sea Side
    - CROSSINGS_LANDSIDE [`output shapes`] : Crossings at Land Side
    - DISTANCES [`output shapes`] : Distances to profile start point. Distances > 0 if towards sea side (acretion) and < 0 if towards landside (erosion)
    - ATTRIBUTES [`choice`] : Parent Attributes. Available Choices: [0] index [1] attributes [2] index and attributes Default: 0 attributes inherited by parent lines layers

    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
    Returns
    ----------
    `boolean` : `True` on success, `False` on failure.
    '''
    Tool = Tool_Wrapper('ta_cliffmetrics', '1', 'Coastal Profile Crossings')
    if Tool.is_Okay():
        Tool.Set_Input ('LINES_SeaSide', LINES_SEASIDE)
        Tool.Set_Input ('LINES_LandSide', LINES_LANDSIDE)
        Tool.Set_Input ('LINES_Coast', LINES_COAST)
        Tool.Set_Output('CROSSINGS_SEASIDE', CROSSINGS_SEASIDE)
        Tool.Set_Output('CROSSINGS_LANDSIDE', CROSSINGS_LANDSIDE)
        Tool.Set_Output('DISTANCES', DISTANCES)
        Tool.Set_Option('ATTRIBUTES', ATTRIBUTES)
        return Tool.Execute(Verbose)
    return False

